OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Няма споделяния",
    "Downloaded via public link" : "Изтеглен чрез публична връзка",
    "Downloaded by {email}" : "Изтеглен от {email}",
    "{file} downloaded via public link" : "{file} е изтеглен чрез обществена връзка",
    "{email} downloaded {file}" : "{email} изтегли {file}",
    "Shared with group {group}" : "Споделен с група {group}",
    "Removed share for group {group}" : "Премахнато е споделянето за група {group}",
    "{actor} shared with group {group}" : "{actor} сподели с група {group}",
    "{actor} removed share for group {group}" : "{actor} премахна споделяне с група {group}",
    "Share for group {group} expired" : "Споделянето за група {group} изтече",
    "You shared {file} with group {group}" : "Споделихте {file} с група {group}",
    "You removed group {group} from {file}" : "Премахнахте група {group} от {file}",
    "{actor} shared {file} with group {group}" : "{actor} сподели {file} с група {group}",
    "{actor} removed group {group} from {file}" : "{actor} премахна група {group} от {file}",
    "Share for file {file} with group {group} expired" : "Споделянето за файл {file} с група {group} изтече",
    "Shared as public link" : "Споделено с публична връзка",
    "Removed public link" : "Премахни публичната връзка",
    "Public link expired" : "Публичната връзка изтече",
    "{actor} shared as public link" : "{actor} споделен като обществена връзка",
    "{actor} removed public link" : "{actor} премахна публичната връзка",
    "Public link of {actor} expired" : "Публичната връзка за {actor} изтече",
    "You shared {file} as public link" : "Споделихте {file} с публична връзка",
    "You removed public link for {file}" : "Премахнахте публична връзка към файла {file}",
    "Public link expired for {file}" : "Публичната връзка за {file} изтече",
    "{actor} shared {file} as public link" : "{actor} сподели като  {file} обществена връзка",
    "{actor} removed public link for {file}" : "{actor} премахна публичната връзка за  {file}",
    "Public link of {actor} for {file} expired" : "Публичната връзка на {actor} за {file} изтече",
    "{user} accepted the remote share" : "{user} прие отдалеченото споделяне",
    "{user} declined the remote share" : "{user} отказа отдалеченото споделяне",
    "You received a new remote share {file} from {user}" : "Получихте ново отдалечено споделяне {file} от {user}",
    "{user} accepted the remote share of {file}" : "{user} прие отдалеченото споделяне от {file}",
    "{user} declined the remote share of {file}" : "{user} отказа отдалеченото споделяне от {file}",
    "{user} unshared {file} from you" : "{user} прекрати споделяне на{file} от вас",
    "Shared with {user}" : "Споделен с {user}",
    "Removed share for {user}" : "Премахнато споделяне за {user}",
    "You removed yourself" : "Вие се отстранихте",
    "{actor} removed themselves" : "{actor} се премахнаха",
    "{actor} shared with {user}" : "{actor} сподели с {user}",
    "{actor} removed share for {user}" : "{actor} премахна споделеното за {user}",
    "Shared by {actor}" : "Споделено от {actor}",
    "{actor} removed share" : "{actor} премахна споделеното",
    "Share for {user} expired" : "Споделянето за група {user} изтече",
    "Share expired" : "Споделянето изтече",
    "You shared {file} with {user}" : "Споделихте {file} с {user}",
    "You removed {user} from {file}" : "Премахнахте {user} от {file}",
    "You removed yourself from {file}" : "Вие се отстранихте от {file}",
    "{actor} removed themselves from {file}" : "{actor} се премахнаха от {file}",
    "{actor} shared {file} with {user}" : "{actor} сподели {file} с {user}",
    "{actor} removed {user} from {file}" : "{actor} премахна {user} от {file}",
    "{actor} shared {file} with you" : "{actor} сподели {file} с вас",
    "{actor} removed you from the share named {file}" : "{actor} ви премахна от споделянето с име {file}",
    "Share for file {file} with {user} expired" : "Споделянето за файл {file} с {user} изтече",
    "Share for file {file} expired" : "Споделянето за файл {file} изтече",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "<strong>Сваляне</strong>на файл, споделен чрез имейл или публична връзка",
    "A file or folder was shared from <strong>another server</strong>" : "Споделяне на файл / папка с <strong>друг сървър</strong>",
    "Sharing" : "Споделяне",
    "A file or folder has been <strong>shared</strong>" : "<strong>Споделяне</strong> на файл / папка",
    "Shared link" : "Споделена връзка",
    "Wrong share ID, share does not exist" : "Грешен идентификатор на споделяне, споделянето не съществува",
    "Could not delete share" : "Не е възможно изтриване на споделянето",
    "Please specify a file or folder path" : "Моля въведете път до файл или папка",
    "Wrong path, file/folder does not exist" : "Грешен път, файл/папка не съществува",
    "Could not create share" : "Не е възможно създаването на споделянето",
    "Group sharing is disabled by the administrator" : "Груповото споделяне е спряно от администратора",
    "Please specify a valid group" : "Моля въведете валидна група",
    "Public link sharing is disabled by the administrator" : "Публичното споделяне на линкове е спряно от администратора",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Споделянето %s на изпращането на паролата от Nextcloud Talk не бе успешно, тъй като Nextcloud Talk не е активирано",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Споделянето %1$s не бе успешно, защото вътрешния сървър не позволява споделяния от тип %2$s",
    "Please specify a valid federated group ID" : "Моля, посочете валиден идентификатор на федерирана група",
    "Sharing %s failed because the back end does not support room shares" : "Споделянето %s не бе успешно, защото вътрешния сървър не позволява споделяния на стаите",
    "Unknown share type" : "Неизвестен тип споделяне",
    "Not a directory" : "Не е  директория",
    "Could not lock node" : "Възелът не можа да се заключи",
    "Public upload is only possible for publicly shared folders" : "Публичното качване е възможно само за публично споделени папки",
    "Share must at least have READ or CREATE permissions" : "Споделянето трябва да има права поне за ЧЕТЕНЕ или СЪЗДАВАНЕ",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Споделянето трябва да има право за ЧЕТЕНЕ ако е зададено право за ОБНОВЯВАНЕ или за ИЗТРИВАНЕ",
    "Public upload disabled by the administrator" : "Публичното качване е е спряно от администратора",
    "Could not lock path" : "Пътя не можа да се заключи",
    "Wrong or no update parameter given" : "Грешен или не е даден параметър за актуализация",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "„Изпращането на паролата от Nextcloud Talk“ за споделяне на файл или папка не беше успешно, тъй като Nextcloud Talk не е активиран.",
    "Wrong password" : "Грешна парола",
    "shared by %s" : "споделено от %s",
    "Download" : "Изтегли",
    "Add to your %s" : "Добавяне към вашия %s",
    "Direct link" : "Директна връзка",
    "Share API is disabled" : "Споделянето на API  е изключено",
    "File sharing" : "Споделяне на файлове",
    "Share will expire tomorrow" : "Споделянето ще изтече утре",
    "Your share of {node} will expire tomorrow" : "Вашето споделяне на {node} ще изтече утре",
    "You received {share} as a share by {user}" : "Получихте {share} като споделяне от {user}",
    "You received {share} to group {group} as a share by {user}" : "Получихте {share} за група {group} като споделяне от {user}",
    "Accept" : "Приемане",
    "Decline" : "Отхвърляне",
    "you" : "ти",
    "Expiration date" : "Валидност",
    "Select a date" : "Избор на дата",
    "Set a password" : "Задаване на парола",
    "Password" : "Парола",
    "Link copied" : "Връзката е копирана",
    "Share link" : "Връзка за споделяне",
    "Copy" : "Копие",
    "Send link via email" : "Сподели връзка с имейл",
    "Select" : "Избери",
    "The uploaded files are visible only to you unless you choose to share them." : "Качените файлове са видими само за теб, освен, ако не решиш да ги споделиш с друг.",
    "Close" : "Затваряне",
    "Error creating the share: {errorMessage}" : "Грешка при създаване на споделянето: {errorMessage}",
    "Error creating the share" : "Грешка при създаване на споделянето",
    "Cancel" : "Отказ",
    "Continue" : "Продължаване",
    "Error while toggling options" : "Грешка при превключване на опциите",
    "Choose a default folder for accepted shares" : "Избор на папка по подразбиране за приети споделяния",
    "Invalid path selected" : "Избран е невалиден път ",
    "Unknown error" : "Неизвестна грешка",
    "Set default folder for accepted shares" : "Задаване на папка по подразбиране за приети споделяния",
    "Reset" : "Възстановяване",
    "Reset folder to system default" : "Възстановяване на папка по подразбиране на системата",
    "group" : "група",
    "conversation" : "разговор",
    "remote" : "отдалечен",
    "remote group" : "отдалечена група",
    "guest" : "гост",
    "Shared with the group {user} by {owner}" : "Споделено с групата {user} от {owner}",
    "Shared with the conversation {user} by {owner}" : "Споделено с разговора {user} от {owner}",
    "Shared with {user} by {owner}" : "Споделено с {user} от {owner}",
    "Added by {initiator}" : "Добавено от {initiator}",
    "Via “{folder}”" : "Чрез “{folder}”",
    "Unshare" : "Прекрати споделянето",
    "Cannot copy, please copy the link manually" : "Не може да се копира, моля, копирайте връзката ръчно",
    "Copy internal link" : "Копиране на вътрешна връзка",
    "Internal link" : "Вътрешна връзка",
    "{shareWith} by {initiator}" : "{shareWith} чрез {initiator}",
    "Shared via link by {initiator}" : "Споделено чрез връзка от {initiator}",
    "Mail share ({label})" : "Споделяне на поща ({label})",
    "Share link ({label})" : "Споделяне на връзка ({label})",
    "Share link ({index})" : "Споделяне на връзка ({index})",
    "Create public link" : "Създаване на публична връзка",
    "Actions for \"{title}\"" : "Действия за „{title}“",
    "Error, please enter proper password and/or expiration date" : "Грешка, моля да въведете правилната парола и / или срок на годност",
    "Link share created" : "Създадено споделяне на връзка",
    "Error while creating the share" : "Грешка при създаване на споделянето",
    "Please enter the following required information before creating the share" : "Моля, въведете следната необходима информация, преди да създадете споделянето",
    "Password protection (enforced)" : "Защита с парола (приложена)",
    "Password protection" : "Password protection",
    "Enter a password" : "Въведете парола",
    "Create share" : "Създаване на споделяне",
    "Add another link" : "Добави още една връзка",
    "Create a new share link" : "Създаване на нова връзка за споделяне",
    "View only" : "Само изглед",
    "Can edit" : "Може да се редактира",
    "Custom permissions" : "Персонализиране на права",
    "Resharing is not allowed" : "Повторното споделяне е забранено",
    "No elements found." : "Няма намерени елементи",
    "Search everywhere" : "Търси навсякъде",
    "Guest" : "Гост",
    "Group" : "Група",
    "Email" : "Имейл",
    "Team" : "Екип",
    "Talk conversation" : "Talk разговор",
    "Deck board" : "Deck табло",
    "ScienceMesh" : "ScienceMesh /приложение/",
    "on {server}" : "на {server}",
    "Search for internal recipients" : "Търси вътрешни получатели",
    "File drop" : "Пускане/Преместване/ на файл",
    "Terms of service" : "Условия за ползване",
    "Read" : "Четене",
    "Create" : "Създаване",
    "Edit" : "Редактиране",
    "Share" : "Сподели",
    "Delete" : "Изтрий",
    "Allow upload and editing" : "За качване и редактиране",
    "Allow editing" : "Разреши редактиране",
    "Advanced settings" : "Допълнителни настройки",
    "Share label" : " Споделяне на етикет",
    "Password expires {passwordExpirationTime}" : "Паролата изтича {passwordExpirationTime}",
    "Password expired" : "Паролата е изтекла",
    "Video verification" : "Видео потвърждение",
    "Expiration date (enforced)" : "Дата на изтичане (приложена)",
    "Set expiration date" : "Срок на валидност",
    "Hide download" : "Скрий свалянето",
    "Note to recipient" : "Бележка за получателя",
    "Enter a note for the share recipient" : "Въведете бележка за получателя на споделянето",
    "Others with access" : "Други с достъп",
    "Toggle list of others with access to this directory" : "Превключване на списък с други имащи достъп до тази директория",
    "Toggle list of others with access to this file" : "Превключване на списък с други имащи достъп до този файл",
    "Unable to fetch inherited shares" : "Неуспешно извличане на наследени дялове",
    "Shares" : "Споделени",
    "Unable to load the shares list" : " Списъкът за споделяне не може да се зареди",
    "Expires {relativetime}" : "Изтича {relativetime}",
    "this share just expired." : "Това споделяне току-що изтече.",
    "Shared with you by {owner}" : "Споделено с Вас от {owner}.",
    "Link to a file" : "Линк към файл",
    "Open in Files" : "Отворете във Файлове",
    "Shared" : "Споделен",
    "Shared multiple times with different people" : "Споделяно многократно с различни хора",
    "Sharing options" : "Опции за споделяне",
    "Shared with others" : "Споделени с други",
    "People" : "Хора",
    "No file" : "Без файл",
    "No shares" : "Няма споделяния",
    "Shared with you" : "Споделени с вас",
    "Nothing shared with you yet" : "Няма споделени файлове",
    "Nothing shared yet" : "Няма споделени файлове",
    "Shared by link" : "Споделени с връзка",
    "No shared links" : "Няма споделени връзки",
    "Deleted shares" : "Изтрити",
    "No deleted shares" : "Няма изтрити споделяния",
    "Pending shares" : "Чакащи споделяния",
    "No pending shares" : "Няма чакащи споделяния",
    "Error updating the share: {errorMessage}" : "Грешка приактуализиране на споделянето: {errorMessage}",
    "Error updating the share" : "Грешка при актуализиране на споделянето",
    "File \"{path}\" has been unshared" : "Файл „{path}“ не е споделен",
    "Folder \"{path}\" has been unshared" : "Папка „{path}“не е споделена",
    "Share label saved" : "Запазен е етикет за споделяне",
    "Share password saved" : "Запазена е парола за споделяне",
    "Password created successfully" : "Създаването на парола е успешно",
    "Error generating password from password policy" : "Грешка при генериране на парола от политиката за пароли",
    "Shared with you and the group {group} by {owner}" : "Споделено от {owner} с Вас и групата {group} .",
    "Shared with you and {circle} by {owner}" : "Споделено с вас и {circle} от {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Споделено с вас и разговора {conversation} от {owner}",
    "Shared with you in a conversation by {owner}" : "Споделено с вас в разговор от {owner}",
    "Share not found" : "Споделянето не е открито",
    "Back to %s" : "Обратно към %s",
    "Add to your Nextcloud" : "Добавете към Nextcloud",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Споделянето %s не бе успешно, защото вътрешния сървър не позволява споделяния на приложението ScienceMesh",
    "Link copied to clipboard" : "Връзката е копирана в клипборда",
    "Copy to clipboard" : "Копиране в клипборда",
    "Copy internal link to clipboard" : "Копиране на вътрешна връзката в клипборда",
    "Copy public link of \"{title}\" to clipboard" : "Копиране на публичната връзка на „{title}“ в клипборда",
    "Name or email …" : "Име или имейл",
    "Name, email, or Federated Cloud ID …" : "Име, имейл или Federed Cloud ID/ИД за облачно пространство/ ...",
    "Searching …" : "Търсене ...",
    "Search globally" : "Глобално търсене ",
    "Name" : "Име",
    "Enter your name" : "Въведете вашето име",
    "Filename must not be empty." : "Името на файла не трябва да е празно.",
    "Shared by" : "Споделено от",
    "Shared with" : "Споделено с",
    "Share note" : "Сподели бележка",
    "Show list view" : "Показване с изглед на списък",
    "Show grid view" : "Показване в решетъчен изглед",
    "Upload files to %s" : "Качване на файлове към %s",
    "Note" : "Бележка",
    "Select or drop files" : "Изберете файл или преместете с мишката",
    "Uploading files" : "Качване на файлове",
    "Uploaded files:" : "Качени файлове:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "С качването на файлове, вие се съгласявате с %1$s условията на услугата%2$s."
},
"nplurals=2; plural=(n != 1);");
